dottorrent
==========

High-level Python 3 library for creating .torrent files

Documentation
-------------

Full documentation on how to use dottorrent
is available at `dottorrent.readthedocs.io <http://dottorrent.readthedocs.io>`_.

.. image:: https://readthedocs.org/projects/dottorrent/badge/


Installation
------------

Stable releases are available on PyPI and can be installed using ``pip``.
::

	pip install dottorrent


To install from the latest development sources, clone the git repo and run
``pip install .``

CLI and GUI
---

Looking for a command-line interface? Check out `dottorrent-gui <https://github.com/kz26/dottorrent-cli>`_.    
Looking for a GUI? Check out `dottorrent-gui <https://github.com/kz26/dottorrent-gui>`_.

License
-------

`MIT <https://opensource.org/licenses/MIT>`_
